@@ -119,58 +119,72 @@ _COMBINING = (
         (0x711, 0x711), (0x730, 0x74a), (0x7a6, 0x7b0),
         (0x7eb, 0x7f3), (0x816, 0x819), (0x81b, 0x823),
         (0x825, 0x827), (0x829, 0x82d), (0x859, 0x85b),
-        (0x901, 0x902), (0x93c, 0x93c), (0x941, 0x948),
-        (0x94d, 0x94d), (0x951, 0x954), (0x962, 0x963),
-        (0x981, 0x981), (0x9bc, 0x9bc), (0x9c1, 0x9c4),
-        (0x9cd, 0x9cd), (0x9e2, 0x9e3), (0xa01, 0xa02),
-        (0xa3c, 0xa3c), (0xa41, 0xa42), (0xa47, 0xa48),
-        (0xa4b, 0xa4d), (0xa70, 0xa71), (0xa81, 0xa82),
-        (0xabc, 0xabc), (0xac1, 0xac5), (0xac7, 0xac8),
-        (0xacd, 0xacd), (0xae2, 0xae3), (0xb01, 0xb01),
-        (0xb3c, 0xb3c), (0xb3f, 0xb3f), (0xb41, 0xb43),
-        (0xb4d, 0xb4d), (0xb56, 0xb56), (0xb82, 0xb82),
-        (0xbc0, 0xbc0), (0xbcd, 0xbcd), (0xc3e, 0xc40),
-        (0xc46, 0xc48), (0xc4a, 0xc4d), (0xc55, 0xc56),
-        (0xcbc, 0xcbc), (0xcbf, 0xcbf), (0xcc6, 0xcc6),
-        (0xccc, 0xccd), (0xce2, 0xce3), (0xd41, 0xd43),
-        (0xd4d, 0xd4d), (0xdca, 0xdca), (0xdd2, 0xdd4),
-        (0xdd6, 0xdd6), (0xe31, 0xe31), (0xe34, 0xe3a),
-        (0xe47, 0xe4e), (0xeb1, 0xeb1), (0xeb4, 0xeb9),
-        (0xebb, 0xebc), (0xec8, 0xecd), (0xf18, 0xf19),
-        (0xf35, 0xf35), (0xf37, 0xf37), (0xf39, 0xf39),
-        (0xf71, 0xf7e), (0xf80, 0xf84), (0xf86, 0xf87),
-        (0xf90, 0xf97), (0xf99, 0xfbc), (0xfc6, 0xfc6),
-        (0x102d, 0x1030), (0x1032, 0x1032), (0x1036, 0x1037),
-        (0x1039, 0x103a), (0x1058, 0x1059), (0x108d, 0x108d),
-        (0x1160, 0x11ff), (0x135d, 0x135f), (0x1712, 0x1714),
-        (0x1732, 0x1734), (0x1752, 0x1753), (0x1772, 0x1773),
-        (0x17b4, 0x17b5), (0x17b7, 0x17bd), (0x17c6, 0x17c6),
-        (0x17c9, 0x17d3), (0x17dd, 0x17dd), (0x180b, 0x180d),
-        (0x18a9, 0x18a9), (0x1920, 0x1922), (0x1927, 0x1928),
-        (0x1932, 0x1932), (0x1939, 0x193b), (0x1a17, 0x1a18),
-        (0x1a60, 0x1a60), (0x1a75, 0x1a7c), (0x1a7f, 0x1a7f),
+        (0x8d4, 0x8e1), (0x8e3, 0x8ff), (0x901, 0x902),
+        (0x93c, 0x93c), (0x941, 0x948), (0x94d, 0x94d),
+        (0x951, 0x954), (0x962, 0x963), (0x981, 0x981),
+        (0x9bc, 0x9bc), (0x9c1, 0x9c4), (0x9cd, 0x9cd),
+        (0x9e2, 0x9e3), (0xa01, 0xa02), (0xa3c, 0xa3c),
+        (0xa41, 0xa42), (0xa47, 0xa48), (0xa4b, 0xa4d),
+        (0xa70, 0xa71), (0xa81, 0xa82), (0xabc, 0xabc),
+        (0xac1, 0xac5), (0xac7, 0xac8), (0xacd, 0xacd),
+        (0xae2, 0xae3), (0xb01, 0xb01), (0xb3c, 0xb3c),
+        (0xb3f, 0xb3f), (0xb41, 0xb43), (0xb4d, 0xb4d),
+        (0xb56, 0xb56), (0xb82, 0xb82), (0xbc0, 0xbc0),
+        (0xbcd, 0xbcd), (0xc3e, 0xc40), (0xc46, 0xc48),
+        (0xc4a, 0xc4d), (0xc55, 0xc56), (0xcbc, 0xcbc),
+        (0xcbf, 0xcbf), (0xcc6, 0xcc6), (0xccc, 0xccd),
+        (0xce2, 0xce3), (0xd41, 0xd43), (0xd4d, 0xd4d),
+        (0xdca, 0xdca), (0xdd2, 0xdd4), (0xdd6, 0xdd6),
+        (0xe31, 0xe31), (0xe34, 0xe3a), (0xe47, 0xe4e),
+        (0xeb1, 0xeb1), (0xeb4, 0xeb9), (0xebb, 0xebc),
+        (0xec8, 0xecd), (0xf18, 0xf19), (0xf35, 0xf35),
+        (0xf37, 0xf37), (0xf39, 0xf39), (0xf71, 0xf7e),
+        (0xf80, 0xf84), (0xf86, 0xf87), (0xf90, 0xf97),
+        (0xf99, 0xfbc), (0xfc6, 0xfc6), (0x102d, 0x1030),
+        (0x1032, 0x1032), (0x1036, 0x1037), (0x1039, 0x103a),
+        (0x1058, 0x1059), (0x108d, 0x108d), (0x1160, 0x11ff),
+        (0x135d, 0x135f), (0x1712, 0x1714), (0x1732, 0x1734),
+        (0x1752, 0x1753), (0x1772, 0x1773), (0x17b4, 0x17b5),
+        (0x17b7, 0x17bd), (0x17c6, 0x17c6), (0x17c9, 0x17d3),
+        (0x17dd, 0x17dd), (0x180b, 0x180d), (0x18a9, 0x18a9),
+        (0x1920, 0x1922), (0x1927, 0x1928), (0x1932, 0x1932),
+        (0x1939, 0x193b), (0x1a17, 0x1a18), (0x1a60, 0x1a60),
+        (0x1a75, 0x1a7c), (0x1a7f, 0x1a7f), (0x1ab0, 0x1abd),
         (0x1b00, 0x1b03), (0x1b34, 0x1b34), (0x1b36, 0x1b3a),
         (0x1b3c, 0x1b3c), (0x1b42, 0x1b42), (0x1b44, 0x1b44),
-        (0x1b6b, 0x1b73), (0x1baa, 0x1baa), (0x1be6, 0x1be6),
+        (0x1b6b, 0x1b73), (0x1baa, 0x1bab), (0x1be6, 0x1be6),
         (0x1bf2, 0x1bf3), (0x1c37, 0x1c37), (0x1cd0, 0x1cd2),
         (0x1cd4, 0x1ce0), (0x1ce2, 0x1ce8), (0x1ced, 0x1ced),
-        (0x1dc0, 0x1de6), (0x1dfc, 0x1dff), (0x200b, 0x200f),
-        (0x202a, 0x202e), (0x2060, 0x2063), (0x206a, 0x206f),
-        (0x20d0, 0x20f0), (0x2cef, 0x2cf1), (0x2d7f, 0x2d7f),
-        (0x2de0, 0x2dff), (0x302a, 0x302f), (0x3099, 0x309a),
-        (0xa66f, 0xa66f), (0xa67c, 0xa67d), (0xa6f0, 0xa6f1),
+        (0x1cf4, 0x1cf4), (0x1cf8, 0x1cf9), (0x1dc0, 0x1df5),
+        (0x1dfb, 0x1dff), (0x200b, 0x200f), (0x202a, 0x202e),
+        (0x2060, 0x2063), (0x206a, 0x206f), (0x20d0, 0x20f0),
+        (0x2cef, 0x2cf1), (0x2d7f, 0x2d7f), (0x2de0, 0x2dff),
+        (0x302a, 0x302f), (0x3099, 0x309a), (0xa66f, 0xa66f),
+        (0xa674, 0xa67d), (0xa69e, 0xa69f), (0xa6f0, 0xa6f1),
         (0xa806, 0xa806), (0xa80b, 0xa80b), (0xa825, 0xa826),
         (0xa8c4, 0xa8c4), (0xa8e0, 0xa8f1), (0xa92b, 0xa92d),
         (0xa953, 0xa953), (0xa9b3, 0xa9b3), (0xa9c0, 0xa9c0),
         (0xaab0, 0xaab0), (0xaab2, 0xaab4), (0xaab7, 0xaab8),
-        (0xaabe, 0xaabf), (0xaac1, 0xaac1), (0xabed, 0xabed),
-        (0xfb1e, 0xfb1e), (0xfe00, 0xfe0f), (0xfe20, 0xfe26),
-        (0xfeff, 0xfeff), (0xfff9, 0xfffb), (0x101fd, 0x101fd),
+        (0xaabe, 0xaabf), (0xaac1, 0xaac1), (0xaaf6, 0xaaf6),
+        (0xabed, 0xabed), (0xfb1e, 0xfb1e), (0xfe00, 0xfe0f),
+        (0xfe20, 0xfe2f), (0xfeff, 0xfeff), (0xfff9, 0xfffb),
+        (0x101fd, 0x101fd), (0x102e0, 0x102e0), (0x10376, 0x1037a),
         (0x10a01, 0x10a03), (0x10a05, 0x10a06), (0x10a0c, 0x10a0f),
-        (0x10a38, 0x10a3a), (0x10a3f, 0x10a3f), (0x11046, 0x11046),
-        (0x110b9, 0x110ba), (0x1d165, 0x1d169), (0x1d16d, 0x1d182),
+        (0x10a38, 0x10a3a), (0x10a3f, 0x10a3f), (0x10ae5, 0x10ae6),
+        (0x11046, 0x11046), (0x1107f, 0x1107f), (0x110b9, 0x110ba),
+        (0x11100, 0x11102), (0x11133, 0x11134), (0x11173, 0x11173),
+        (0x111c0, 0x111c0), (0x111ca, 0x111ca), (0x11235, 0x11236),
+        (0x112e9, 0x112ea), (0x1133c, 0x1133c), (0x1134d, 0x1134d),
+        (0x11366, 0x1136c), (0x11370, 0x11374), (0x11442, 0x11442),
+        (0x11446, 0x11446), (0x114c2, 0x114c3), (0x115bf, 0x115c0),
+        (0x1163f, 0x1163f), (0x116b6, 0x116b7), (0x1172b, 0x1172b),
+        (0x11c3f, 0x11c3f), (0x16af0, 0x16af4), (0x16b30, 0x16b36),
+        (0x1bc9e, 0x1bc9e), (0x1d165, 0x1d169), (0x1d16d, 0x1d182),
         (0x1d185, 0x1d18b), (0x1d1aa, 0x1d1ad), (0x1d242, 0x1d244),
-        (0xe0001, 0xe0001), (0xe0020, 0xe007f), (0xe0100, 0xe01ef), )
+        (0x1e000, 0x1e006), (0x1e008, 0x1e018), (0x1e01b, 0x1e021),
+        (0x1e023, 0x1e024), (0x1e026, 0x1e02a), (0x1e8d0, 0x1e8d6),
+        (0x1e944, 0x1e94a), (0xe0001, 0xe0001), (0xe0020, 0xe007f),
+        (0xe0100, 0xe01ef), )
 
 '''
 Internal table, provided by this module to list :term:`code points` which
@@ -185,8 +199,8 @@ a combining character.
     :func:`~kitchen.text.display._generate_combining_table`
         for how this table is generated
 
-This table was last regenerated on python-3.2.3 with
-:data:`unicodedata.unidata_version` 6.0.0
+This table was last regenerated on python-3.6.0-rc1 with
+:data:`unicodedata.unidata_version` 9.0.0
 '''
 
 # New function from Toshio Kuratomi (LGPLv2+)
@@ -215,58 +229,58 @@ def _generate_combining_table():
     # characters generated ifrom Unicode 5.0 data by:
     # "uniset +cat=Me +cat=Mn +cat=Cf -00AD +1160-11FF +200B c"
     markus_kuhn_combining_5_0 = (
-        ( 0x0300, 0x036F ), ( 0x0483, 0x0486 ), ( 0x0488, 0x0489 ),
-        ( 0x0591, 0x05BD ), ( 0x05BF, 0x05BF ), ( 0x05C1, 0x05C2 ),
-        ( 0x05C4, 0x05C5 ), ( 0x05C7, 0x05C7 ), ( 0x0600, 0x0603 ),
-        ( 0x0610, 0x0615 ), ( 0x064B, 0x065E ), ( 0x0670, 0x0670 ),
-        ( 0x06D6, 0x06E4 ), ( 0x06E7, 0x06E8 ), ( 0x06EA, 0x06ED ),
-        ( 0x070F, 0x070F ), ( 0x0711, 0x0711 ), ( 0x0730, 0x074A ),
-        ( 0x07A6, 0x07B0 ), ( 0x07EB, 0x07F3 ), ( 0x0901, 0x0902 ),
-        ( 0x093C, 0x093C ), ( 0x0941, 0x0948 ), ( 0x094D, 0x094D ),
-        ( 0x0951, 0x0954 ), ( 0x0962, 0x0963 ), ( 0x0981, 0x0981 ),
-        ( 0x09BC, 0x09BC ), ( 0x09C1, 0x09C4 ), ( 0x09CD, 0x09CD ),
-        ( 0x09E2, 0x09E3 ), ( 0x0A01, 0x0A02 ), ( 0x0A3C, 0x0A3C ),
-        ( 0x0A41, 0x0A42 ), ( 0x0A47, 0x0A48 ), ( 0x0A4B, 0x0A4D ),
-        ( 0x0A70, 0x0A71 ), ( 0x0A81, 0x0A82 ), ( 0x0ABC, 0x0ABC ),
-        ( 0x0AC1, 0x0AC5 ), ( 0x0AC7, 0x0AC8 ), ( 0x0ACD, 0x0ACD ),
-        ( 0x0AE2, 0x0AE3 ), ( 0x0B01, 0x0B01 ), ( 0x0B3C, 0x0B3C ),
-        ( 0x0B3F, 0x0B3F ), ( 0x0B41, 0x0B43 ), ( 0x0B4D, 0x0B4D ),
-        ( 0x0B56, 0x0B56 ), ( 0x0B82, 0x0B82 ), ( 0x0BC0, 0x0BC0 ),
-        ( 0x0BCD, 0x0BCD ), ( 0x0C3E, 0x0C40 ), ( 0x0C46, 0x0C48 ),
-        ( 0x0C4A, 0x0C4D ), ( 0x0C55, 0x0C56 ), ( 0x0CBC, 0x0CBC ),
-        ( 0x0CBF, 0x0CBF ), ( 0x0CC6, 0x0CC6 ), ( 0x0CCC, 0x0CCD ),
-        ( 0x0CE2, 0x0CE3 ), ( 0x0D41, 0x0D43 ), ( 0x0D4D, 0x0D4D ),
-        ( 0x0DCA, 0x0DCA ), ( 0x0DD2, 0x0DD4 ), ( 0x0DD6, 0x0DD6 ),
-        ( 0x0E31, 0x0E31 ), ( 0x0E34, 0x0E3A ), ( 0x0E47, 0x0E4E ),
-        ( 0x0EB1, 0x0EB1 ), ( 0x0EB4, 0x0EB9 ), ( 0x0EBB, 0x0EBC ),
-        ( 0x0EC8, 0x0ECD ), ( 0x0F18, 0x0F19 ), ( 0x0F35, 0x0F35 ),
-        ( 0x0F37, 0x0F37 ), ( 0x0F39, 0x0F39 ), ( 0x0F71, 0x0F7E ),
-        ( 0x0F80, 0x0F84 ), ( 0x0F86, 0x0F87 ), ( 0x0F90, 0x0F97 ),
-        ( 0x0F99, 0x0FBC ), ( 0x0FC6, 0x0FC6 ), ( 0x102D, 0x1030 ),
-        ( 0x1032, 0x1032 ), ( 0x1036, 0x1037 ), ( 0x1039, 0x1039 ),
-        ( 0x1058, 0x1059 ), ( 0x1160, 0x11FF ), ( 0x135F, 0x135F ),
-        ( 0x1712, 0x1714 ), ( 0x1732, 0x1734 ), ( 0x1752, 0x1753 ),
-        ( 0x1772, 0x1773 ), ( 0x17B4, 0x17B5 ), ( 0x17B7, 0x17BD ),
-        ( 0x17C6, 0x17C6 ), ( 0x17C9, 0x17D3 ), ( 0x17DD, 0x17DD ),
-        ( 0x180B, 0x180D ), ( 0x18A9, 0x18A9 ), ( 0x1920, 0x1922 ),
-        ( 0x1927, 0x1928 ), ( 0x1932, 0x1932 ), ( 0x1939, 0x193B ),
-        ( 0x1A17, 0x1A18 ), ( 0x1B00, 0x1B03 ), ( 0x1B34, 0x1B34 ),
-        ( 0x1B36, 0x1B3A ), ( 0x1B3C, 0x1B3C ), ( 0x1B42, 0x1B42 ),
-        ( 0x1B6B, 0x1B73 ), ( 0x1DC0, 0x1DCA ), ( 0x1DFE, 0x1DFF ),
-        ( 0x200B, 0x200F ), ( 0x202A, 0x202E ), ( 0x2060, 0x2063 ),
-        ( 0x206A, 0x206F ), ( 0x20D0, 0x20EF ), ( 0x302A, 0x302F ),
-        ( 0x3099, 0x309A ), ( 0xA806, 0xA806 ), ( 0xA80B, 0xA80B ),
-        ( 0xA825, 0xA826 ), ( 0xFB1E, 0xFB1E ), ( 0xFE00, 0xFE0F ),
-        ( 0xFE20, 0xFE23 ), ( 0xFEFF, 0xFEFF ), ( 0xFFF9, 0xFFFB ),
-        ( 0x10A01, 0x10A03 ), ( 0x10A05, 0x10A06 ), ( 0x10A0C, 0x10A0F ),
-        ( 0x10A38, 0x10A3A ), ( 0x10A3F, 0x10A3F ), ( 0x1D167, 0x1D169 ),
-        ( 0x1D173, 0x1D182 ), ( 0x1D185, 0x1D18B ), ( 0x1D1AA, 0x1D1AD ),
-        ( 0x1D242, 0x1D244 ), ( 0xE0001, 0xE0001 ), ( 0xE0020, 0xE007F ),
-        ( 0xE0100, 0xE01EF ))
+        (0x0300, 0x036F), (0x0483, 0x0486), (0x0488, 0x0489),
+        (0x0591, 0x05BD), (0x05BF, 0x05BF), (0x05C1, 0x05C2),
+        (0x05C4, 0x05C5), (0x05C7, 0x05C7), (0x0600, 0x0603),
+        (0x0610, 0x0615), (0x064B, 0x065E), (0x0670, 0x0670),
+        (0x06D6, 0x06E4), (0x06E7, 0x06E8), (0x06EA, 0x06ED),
+        (0x070F, 0x070F), (0x0711, 0x0711), (0x0730, 0x074A),
+        (0x07A6, 0x07B0), (0x07EB, 0x07F3), (0x0901, 0x0902),
+        (0x093C, 0x093C), (0x0941, 0x0948), (0x094D, 0x094D),
+        (0x0951, 0x0954), (0x0962, 0x0963), (0x0981, 0x0981),
+        (0x09BC, 0x09BC), (0x09C1, 0x09C4), (0x09CD, 0x09CD),
+        (0x09E2, 0x09E3), (0x0A01, 0x0A02), (0x0A3C, 0x0A3C),
+        (0x0A41, 0x0A42), (0x0A47, 0x0A48), (0x0A4B, 0x0A4D),
+        (0x0A70, 0x0A71), (0x0A81, 0x0A82), (0x0ABC, 0x0ABC),
+        (0x0AC1, 0x0AC5), (0x0AC7, 0x0AC8), (0x0ACD, 0x0ACD),
+        (0x0AE2, 0x0AE3), (0x0B01, 0x0B01), (0x0B3C, 0x0B3C),
+        (0x0B3F, 0x0B3F), (0x0B41, 0x0B43), (0x0B4D, 0x0B4D),
+        (0x0B56, 0x0B56), (0x0B82, 0x0B82), (0x0BC0, 0x0BC0),
+        (0x0BCD, 0x0BCD), (0x0C3E, 0x0C40), (0x0C46, 0x0C48),
+        (0x0C4A, 0x0C4D), (0x0C55, 0x0C56), (0x0CBC, 0x0CBC),
+        (0x0CBF, 0x0CBF), (0x0CC6, 0x0CC6), (0x0CCC, 0x0CCD),
+        (0x0CE2, 0x0CE3), (0x0D41, 0x0D43), (0x0D4D, 0x0D4D),
+        (0x0DCA, 0x0DCA), (0x0DD2, 0x0DD4), (0x0DD6, 0x0DD6),
+        (0x0E31, 0x0E31), (0x0E34, 0x0E3A), (0x0E47, 0x0E4E),
+        (0x0EB1, 0x0EB1), (0x0EB4, 0x0EB9), (0x0EBB, 0x0EBC),
+        (0x0EC8, 0x0ECD), (0x0F18, 0x0F19), (0x0F35, 0x0F35),
+        (0x0F37, 0x0F37), (0x0F39, 0x0F39), (0x0F71, 0x0F7E),
+        (0x0F80, 0x0F84), (0x0F86, 0x0F87), (0x0F90, 0x0F97),
+        (0x0F99, 0x0FBC), (0x0FC6, 0x0FC6), (0x102D, 0x1030),
+        (0x1032, 0x1032), (0x1036, 0x1037), (0x1039, 0x1039),
+        (0x1058, 0x1059), (0x1160, 0x11FF), (0x135F, 0x135F),
+        (0x1712, 0x1714), (0x1732, 0x1734), (0x1752, 0x1753),
+        (0x1772, 0x1773), (0x17B4, 0x17B5), (0x17B7, 0x17BD),
+        (0x17C6, 0x17C6), (0x17C9, 0x17D3), (0x17DD, 0x17DD),
+        (0x180B, 0x180D), (0x18A9, 0x18A9), (0x1920, 0x1922),
+        (0x1927, 0x1928), (0x1932, 0x1932), (0x1939, 0x193B),
+        (0x1A17, 0x1A18), (0x1B00, 0x1B03), (0x1B34, 0x1B34),
+        (0x1B36, 0x1B3A), (0x1B3C, 0x1B3C), (0x1B42, 0x1B42),
+        (0x1B6B, 0x1B73), (0x1DC0, 0x1DCA), (0x1DFE, 0x1DFF),
+        (0x200B, 0x200F), (0x202A, 0x202E), (0x2060, 0x2063),
+        (0x206A, 0x206F), (0x20D0, 0x20EF), (0x302A, 0x302F),
+        (0x3099, 0x309A), (0xA806, 0xA806), (0xA80B, 0xA80B),
+        (0xA825, 0xA826), (0xFB1E, 0xFB1E), (0xFE00, 0xFE0F),
+        (0xFE20, 0xFE23), (0xFEFF, 0xFEFF), (0xFFF9, 0xFFFB),
+        (0x10A01, 0x10A03), (0x10A05, 0x10A06), (0x10A0C, 0x10A0F),
+        (0x10A38, 0x10A3A), (0x10A3F, 0x10A3F), (0x1D167, 0x1D169),
+        (0x1D173, 0x1D182), (0x1D185, 0x1D18B), (0x1D1AA, 0x1D1AD),
+        (0x1D242, 0x1D244), (0xE0001, 0xE0001), (0xE0020, 0xE007F),
+        (0xE0100, 0xE01EF))
     combining = []
     in_interval = False
     interval = []
-    for codepoint in xrange (0, 0xFFFFF + 1):
+    for codepoint in xrange(0, 0xFFFFF + 1):
         if _interval_bisearch(codepoint, markus_kuhn_combining_5_0) or \
                 unicodedata.combining(unichr(codepoint)):
             if not in_interval:
